summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--admin/notes/multi-tty2
-rwxr-xr-xadmin/quick-install-emacs2
-rw-r--r--doc/emacs/fixit.texi2
-rw-r--r--doc/misc/org.texi2
-rw-r--r--lisp/ChangeLog4
-rw-r--r--lisp/cedet/semantic/decorate/include.el2
-rw-r--r--lisp/cedet/semantic/grammar.el2
-rw-r--r--lisp/cedet/srecode/ctxt.el2
-rw-r--r--lisp/emacs-lisp/byte-opt.el2
-rw-r--r--lisp/emacs-lisp/checkdoc.el2
-rw-r--r--lisp/emulation/keypad.el2
-rw-r--r--lisp/htmlfontify.el2
-rw-r--r--lisp/mail/mail-extr.el2
-rw-r--r--lisp/mh-e/ChangeLog.14
-rw-r--r--lisp/progmodes/etags.el2
-rw-r--r--lisp/progmodes/hideshow.el2
-rw-r--r--lisp/progmodes/idlw-shell.el2
-rw-r--r--lisp/progmodes/mixal-mode.el36
-rw-r--r--src/bidi.c2
-rw-r--r--src/dispnew.c2
-rw-r--r--src/keyboard.c6
21 files changed, 42 insertions, 42 deletions
diff --git a/admin/notes/multi-tty b/admin/notes/multi-tty
index ad46f493a02..4146c8ffa58 100644
--- a/admin/notes/multi-tty
+++ b/admin/notes/multi-tty
@@ -789,7 +789,7 @@ DIARY OF CHANGES
frame's kboard from there.)
-- Fix rif issue with X-tty combo sessions. IMHO the best thing to do
- is to get rid of that global variable (and use the value value in
+ is to get rid of that global variable (and use the value in
display_method, which is guaranteed to be correct).
(Done, did exactly that. Core dumps during combo sessions became
diff --git a/admin/quick-install-emacs b/admin/quick-install-emacs
index 657dcdc1766..06cd2d40901 100755
--- a/admin/quick-install-emacs
+++ b/admin/quick-install-emacs
@@ -49,7 +49,7 @@ COPY='cp -f'
REMOVE='rm -r'
MKDIR='mkdir -p'
-# Used to execute commands once once we create them
+# Used to execute commands once we create them
EXEC='sh'
NAWK=/usr/bin/nawk
diff --git a/doc/emacs/fixit.texi b/doc/emacs/fixit.texi
index c4fbca6574b..16feb939b33 100644
--- a/doc/emacs/fixit.texi
+++ b/doc/emacs/fixit.texi
@@ -356,7 +356,7 @@ Show the list of options.
In Text mode and related modes, @kbd{M-@key{TAB}}
(@code{ispell-complete-word}) performs in-buffer completion based on
spelling correction. Insert the beginning of a word, and then type
-@kbd{M-@key{TAB}}; this shows shows a list of completions. (If your
+@kbd{M-@key{TAB}}; this shows a list of completions. (If your
window manager intercepts @kbd{M-@key{TAB}}, type @kbd{@key{ESC}
@key{TAB}} or @kbd{C-M-i}.) Each completion is listed with a digit or
character; type that digit or character to choose it.
diff --git a/doc/misc/org.texi b/doc/misc/org.texi
index 4997a290cb7..8da6cd96525 100644
--- a/doc/misc/org.texi
+++ b/doc/misc/org.texi
@@ -7342,7 +7342,7 @@ If you are using the Big Brothers Database to store your contacts, you will
very likely prefer to store anniversaries in BBDB rather than in a
separate Org or diary file. Org supports this and will show BBDB
anniversaries as part of the agenda. All you need to do is to add the
-following to one your your agenda files:
+following to one of your agenda files:
@example
* Anniversaries
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index fedbe71d516..90a2070c87c 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -7131,7 +7131,7 @@
2011-05-23 Kevin Ryde <user42@zip.com.au>
* emacs-lisp/advice.el (ad-read-advised-function):
- Use `function-called-at-point' as the default default, if it has
+ Use `function-called-at-point' as the default, if it has
advice and passes PREDICATE.
2011-05-23 Stefan Monnier <monnier@iro.umontreal.ca>
@@ -7957,7 +7957,7 @@
* net/gnutls.el (gnutls-negotiate): Add hostname, verify-flags,
verify-error, and verify-hostname-error parameters. Check whether
default trustfile exists before going to use it. Add missing
- argument to gnutls-message-maybe call. Return return value.
+ argument to gnutls-message-maybe call. Return value.
Reported by Claudio Bley <claudio.bley@gmail.com>.
(open-gnutls-stream): Add usage example.
diff --git a/lisp/cedet/semantic/decorate/include.el b/lisp/cedet/semantic/decorate/include.el
index 7fd4214016d..50b50398e16 100644
--- a/lisp/cedet/semantic/decorate/include.el
+++ b/lisp/cedet/semantic/decorate/include.el
@@ -45,7 +45,7 @@
(defvar semantic-decoratiton-mouse-3 (if (featurep 'xemacs) [ button3 ] [ mouse-3 ])
"The keybinding lisp object to use for binding the right mouse button.")
-;;; Includes that that are in a happy state!
+;;; Includes that are in a happy state!
;;
(defface semantic-decoration-on-includes
nil
diff --git a/lisp/cedet/semantic/grammar.el b/lisp/cedet/semantic/grammar.el
index 6d7865a29df..ac28702787d 100644
--- a/lisp/cedet/semantic/grammar.el
+++ b/lisp/cedet/semantic/grammar.el
@@ -451,7 +451,7 @@ Also load the specified macro libraries."
',(semantic-grammar-keyword-properties keywords))))
(define-overloadable-function semantic-grammar-keywordtable-builder ()
- "Return the keyword table table value.")
+ "Return the keyword table value.")
;;; Token table builder
;;
diff --git a/lisp/cedet/srecode/ctxt.el b/lisp/cedet/srecode/ctxt.el
index b864316deb5..45f0d2b3afb 100644
--- a/lisp/cedet/srecode/ctxt.el
+++ b/lisp/cedet/srecode/ctxt.el
@@ -41,7 +41,7 @@
(define-overload srecode-calculate-context ()
"Calculate the context at the current point.
The returned context is a list, with the top-most context first.
-Each returned context is a string that that would show up in a `context'
+Each returned context is a string that would show up in a `context'
statement in an `.srt' file.
Some useful context values used by the provided srecode templates are:
diff --git a/lisp/emacs-lisp/byte-opt.el b/lisp/emacs-lisp/byte-opt.el
index 0a845265a37..78ac29d89df 100644
--- a/lisp/emacs-lisp/byte-opt.el
+++ b/lisp/emacs-lisp/byte-opt.el
@@ -1574,7 +1574,7 @@ If FOR-EFFECT is non-nil, the return value is assumed to be of no importance."
;; stack-set-X+1 stack-ref-X --> dup stack-set-X+2
;; but this is a very minor gain, since dup is stack-ref-0,
;; i.e. it's only better if X>5, and even then it comes
- ;; at the cost cost of an extra stack slot. Let's not bother.
+ ;; at the cost of an extra stack slot. Let's not bother.
((and (eq 'byte-varref (car lap2))
(eq (cdr lap1) (cdr lap2))
(memq (car lap1) '(byte-varset byte-varbind)))
diff --git a/lisp/emacs-lisp/checkdoc.el b/lisp/emacs-lisp/checkdoc.el
index fb14382bfd2..7a9a33fc2cc 100644
--- a/lisp/emacs-lisp/checkdoc.el
+++ b/lisp/emacs-lisp/checkdoc.el
@@ -1943,7 +1943,7 @@ from the comment."
A code fragment is identified by an open parenthesis followed by a
symbol which is a valid function or a word in all CAPS, or a parenthesis
that is quoted with the ' character. Only the region from START to LIMIT
-is is allowed while searching for the bounding parenthesis."
+is allowed while searching for the bounding parenthesis."
(save-match-data
(save-restriction
(narrow-to-region start limit)
diff --git a/lisp/emulation/keypad.el b/lisp/emulation/keypad.el
index a49ba33f158..4e2c3b1e886 100644
--- a/lisp/emulation/keypad.el
+++ b/lisp/emulation/keypad.el
@@ -27,7 +27,7 @@
;;
;; With the following setup, the keypad can be used for numeric data
;; entry when NumLock is off, and to give numeric prefix arguments to
-;; emacs commands, when NumLock on on.
+;; emacs commands, when NumLock is on.
;;
;; keypad-setup => Plain Numeric Keypad
;; keypad-numlock-setup => Prefix numeric args
diff --git a/lisp/htmlfontify.el b/lisp/htmlfontify.el
index ac9d2c5ba04..4c811d885d7 100644
--- a/lisp/htmlfontify.el
+++ b/lisp/htmlfontify.el
@@ -861,7 +861,7 @@ which *doesn't* clash with CLASS is returned.\n
\(A specification with a class of t is considered to match any class you
specify - this matches Emacs' behavior when deciding on which face attributes
to use, to the best of my understanding).\n
-If CLASS is nil, then you just get get whatever `face-attr-construct' returns,
+If CLASS is nil, then you just get whatever `face-attr-construct' returns,
ie the current specification in effect for FACE.\n
*NOTE*: This function forces any face that is not 'default and which has
no :inherit property to inherit from 'default (this is because 'default
diff --git a/lisp/mail/mail-extr.el b/lisp/mail/mail-extr.el
index 5012d8af650..6af9c2478fc 100644
--- a/lisp/mail/mail-extr.el
+++ b/lisp/mail/mail-extr.el
@@ -394,7 +394,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\"."
;; Matches ham radio call signs.
;; Help from: Mat Maessen N2NJZ <maessm@rpi.edu>, Mark Feit
;; <mark@era.com>, Michael Covington <mcovingt@ai.uga.edu>.
-;; Examples: DX504 DX515 K5MRU K8DHK KA9WGN KA9WGN KD3FU KD6EUI KD6HBW
+;; Examples: DX504 DX515 K5MRU K8DHK KA9WGN KD3FU KD6EUI KD6HBW
;; KE9TV KF0NV N1API N3FU N3GZE N3IGS N4KCC N7IKQ N9HHU W4YHF W6ANK WA2SUH
;; WB7VZI N2NJZ NR3G KJ4KK AB4UM AL7NI KH6OH WN3KBT N4TMI W1A N0NZO
(defconst mail-extr-ham-call-sign-pattern
diff --git a/lisp/mh-e/ChangeLog.1 b/lisp/mh-e/ChangeLog.1
index 8b4981940ae..94ac7a2f3b7 100644
--- a/lisp/mh-e/ChangeLog.1
+++ b/lisp/mh-e/ChangeLog.1
@@ -2898,7 +2898,7 @@
2003-06-01 Peter S Galbraith <psg@debian.org>
- * mh-comp.el (mh-modify-header-field): Bug fix. Calling with with
+ * mh-comp.el (mh-modify-header-field): Bug fix. Calling with
a value that was already inserted causes it to get inserted a
second time. I have wrapped the value around \b word delimiters.
Hope there are no side effects for other code.
@@ -9952,7 +9952,7 @@
* mh-mime.el (compilation): Code rearrangement to remove compiler
warnings.
(mh-defun-compat): New macro to define to useful functions that
- aren't present present in old Gnus.
+ aren't present in old Gnus.
(mh-destroy-postponed-handles): New function to cleanup handles
that are associated with external viewers.
(mh-handle-set-external-undisplayer): New function to replace
diff --git a/lisp/progmodes/etags.el b/lisp/progmodes/etags.el
index 56f04751bda..cc5f0fef934 100644
--- a/lisp/progmodes/etags.el
+++ b/lisp/progmodes/etags.el
@@ -463,7 +463,7 @@ Returns non-nil if it is a valid table."
;; Subroutine of visit-tags-table-buffer. Search the current tags tables
;; for one that has tags for THIS-FILE (or that includes a table that
-;; does). Return the name of the first table table listing THIS-FILE; if
+;; does). Return the name of the first table listing THIS-FILE; if
;; the table is one included by another table, it is the master table that
;; we return. If CORE-ONLY is non-nil, check only tags tables that are
;; already in buffers--don't visit any new files.
diff --git a/lisp/progmodes/hideshow.el b/lisp/progmodes/hideshow.el
index c9ba5ef2818..0884d28ad5a 100644
--- a/lisp/progmodes/hideshow.el
+++ b/lisp/progmodes/hideshow.el
@@ -604,7 +604,7 @@ we return a list having a nil as its car and the end of comment position
as cdr."
(save-excursion
;; the idea is to look backwards for a comment start regexp, do a
- ;; forward comment, and see if we are inside, then extend extend
+ ;; forward comment, and see if we are inside, then extend
;; forward and backward as long as we have comments
(let ((q (point)))
(when (or (looking-at hs-c-start-regexp)
diff --git a/lisp/progmodes/idlw-shell.el b/lisp/progmodes/idlw-shell.el
index 619b903e902..55a085fbde0 100644
--- a/lisp/progmodes/idlw-shell.el
+++ b/lisp/progmodes/idlw-shell.el
@@ -227,7 +227,7 @@ window, but is useful for stepping, etc."
"Obsolete variable. See `idlwave-shell-debug-modifiers'.")
(defcustom idlwave-shell-use-truename nil
- "*Non-nil means, use use `file-truename' when looking for buffers.
+ "*Non-nil means, use `file-truename' when looking for buffers.
If this variable is non-nil, Emacs will use the function `file-truename' to
resolve symbolic links in the file paths printed by e.g., STOP commands.
This means, unvisited files will be loaded under their truename.
diff --git a/lisp/progmodes/mixal-mode.el b/lisp/progmodes/mixal-mode.el
index b152f7367eb..54d857dd4b1 100644
--- a/lisp/progmodes/mixal-mode.el
+++ b/lisp/progmodes/mixal-mode.el
@@ -145,43 +145,43 @@ zeros to make a word."
(LD1 loading "load I1" 9 field
"Put in rI1 the contents of cell no. M.
Uses a + when there is no sign in subfield. Subfield is left padded with
-zeros to make a word. Index registers only have 2 bytes and a sign, Trying
-to set anything more that that will result in undefined behavior."
+zeros to make a word. Index registers only have 2 bytes and a sign; trying
+to set anything more than that will result in undefined behavior."
2)
(LD2 loading "load I2" 10 field
"Put in rI2 the contents of cell no. M.
Uses a + when there is no sign in subfield. Subfield is left padded with
-zeros to make a word. Index registers only have 2 bytes and a sign, Trying
-to set anything more that that will result in undefined behavior."
+zeros to make a word. Index registers only have 2 bytes and a sign; trying
+to set anything more than that will result in undefined behavior."
2)
(LD3 loading "load I3" 11 field
"Put in rI3 the contents of cell no. M.
Uses a + when there is no sign in subfield. Subfield is left padded with
-zeros to make a word. Index registers only have 2 bytes and a sign, Trying
-to set anything more that that will result in undefined behavior."
+zeros to make a word. Index registers only have 2 bytes and a sign; trying
+to set anything more than that will result in undefined behavior."
2)
(LD4 loading "load I4" 12 field
"Put in rI4 the contents of cell no. M.
Uses a + when there is no sign in subfield. Subfield is left padded with
-zeros to make a word. Index registers only have 2 bytes and a sign, Trying
-to set anything more that that will result in undefined behavior."
+zeros to make a word. Index registers only have 2 bytes and a sign; trying
+to set anything more than that will result in undefined behavior."
2)
(LD5 loading "load I5" 13 field
"Put in rI5 the contents of cell no. M.
Uses a + when there is no sign in subfield. Subfield is left padded with
-zeros to make a word. Index registers only have 2 bytes and a sign, Trying
-to set anything more that that will result in undefined behavior."
+zeros to make a word. Index registers only have 2 bytes and a sign; trying
+to set anything more than that will result in undefined behavior."
2)
(LD6 loading "load I6" 14 field
"Put in rI6 the contents of cell no. M.
Uses a + when there is no sign in subfield. Subfield is left padded with
-zeros to make a word. Index registers only have 2 bytes and a sign, Trying
-to set anything more that that will result in undefined behavior."
+zeros to make a word. Index registers only have 2 bytes and a sign; trying
+to set anything more than that will result in undefined behavior."
2)
(LDAN loading "load A negative" 16 field
@@ -200,7 +200,7 @@ Subfield is left padded with zeros to make a word."
"Put in rI1 the contents of cell no. M, with opposite sign.
Uses a + when there is no sign in subfield, otherwise use the opposite sign.
Subfield is left padded with zeros to make a word. Index registers only
-have 2 bytes and a sign, Trying to set anything more that that will result
+have 2 bytes and a sign; trying to set anything more than that will result
in undefined behavior."
2)
@@ -208,7 +208,7 @@ in undefined behavior."
"Put in rI2 the contents of cell no. M, with opposite sign.
Uses a + when there is no sign in subfield, otherwise use the opposite sign.
Subfield is left padded with zeros to make a word. Index registers only
-have 2 bytes and a sign, Trying to set anything more that that will result
+have 2 bytes and a sign; trying to set anything more than that will result
in undefined behavior."
2)
@@ -216,7 +216,7 @@ in undefined behavior."
"Put in rI3 the contents of cell no. M, with opposite sign.
Uses a + when there is no sign in subfield, otherwise use the opposite sign.
Subfield is left padded with zeros to make a word. Index registers only
-have 2 bytes and a sign, Trying to set anything more that that will result
+have 2 bytes and a sign; trying to set anything more than that will result
in undefined behavior."
2)
@@ -224,7 +224,7 @@ in undefined behavior."
"Put in rI4 the contents of cell no. M, with opposite sign.
Uses a + when there is no sign in subfield, otherwise use the opposite sign.
Subfield is left padded with zeros to make a word. Index registers only
-have 2 bytes and a sign, Trying to set anything more that that will result
+have 2 bytes and a sign; trying to set anything more than that will result
in undefined behavior."
2)
@@ -232,7 +232,7 @@ in undefined behavior."
"Put in rI5 the contents of cell no. M, with opposite sign.
Uses a + when there is no sign in subfield, otherwise use the opposite sign.
Subfield is left padded with zeros to make a word. Index registers only
-have 2 bytes and a sign, Trying to set anything more that that will result
+have 2 bytes and a sign; trying to set anything more than that will result
in undefined behavior."
2)
@@ -240,7 +240,7 @@ in undefined behavior."
"Put in rI6 the contents of cell no. M, with opposite sign.
Uses a + when there is no sign in subfield, otherwise use the opposite sign.
Subfield is left padded with zeros to make a word. Index registers only
-have 2 bytes and a sign, Trying to set anything more that that will result
+have 2 bytes and a sign; trying to set anything more than that will result
in undefined behavior."
2)
diff --git a/src/bidi.c b/src/bidi.c
index b59b838d671..107c817abba 100644
--- a/src/bidi.c
+++ b/src/bidi.c
@@ -572,7 +572,7 @@ bidi_cache_find (EMACS_INT charpos, int level, struct bidi_it *bidi_it)
bidi_copy_it (bidi_it, &bidi_cache[i]);
bidi_cache_last_idx = i;
- /* Don't let scan direction from from the cached state override
+ /* Don't let scan direction from the cached state override
the current scan direction. */
bidi_it->scan_dir = current_scan_dir;
return bidi_it->type;
diff --git a/src/dispnew.c b/src/dispnew.c
index 680c861c382..9e57bbb28bf 100644
--- a/src/dispnew.c
+++ b/src/dispnew.c
@@ -62,7 +62,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
#include <errno.h>
/* Get number of chars of output now in the buffer of a stdio stream.
- This ought to be built in in stdio, but it isn't. Some s- files
+ This ought to be built in stdio, but it isn't. Some s- files
override this because their stdio internals differ. */
#ifdef __GNU_LIBRARY__
diff --git a/src/keyboard.c b/src/keyboard.c
index d684a89038a..c304439f272 100644
--- a/src/keyboard.c
+++ b/src/keyboard.c
@@ -2239,8 +2239,8 @@ do { if (polling_stopped_here) start_polling (); \
polling_stopped_here = 0; } while (0)
/* read a character from the keyboard; call the redisplay if needed */
-/* commandflag 0 means do not do auto-saving, but do do redisplay.
- -1 means do not do redisplay, but do do autosaving.
+/* commandflag 0 means do not autosave, but do redisplay.
+ -1 means do not redisplay, but do autosave.
1 means do both. */
/* The arguments MAPS and NMAPS are for menu prompting.
@@ -5133,7 +5133,7 @@ make_lispy_position (struct frame *f, Lisp_Object x, Lisp_Object y,
if (WINDOWP (window))
{
- /* It's a click in window window at frame coordinates (x,y) */
+ /* It's a click in window WINDOW at frame coordinates (X,Y) */
struct window *w = XWINDOW (window);
Lisp_Object string_info = Qnil;
EMACS_INT textpos = -1;